@@ -2,7 +2,7 @@ import os
 import hashlib
 from enum import Enum as EnumBaseClass
 from functools import wraps
-from typing import BinaryIO, Optional, List
+from typing import Optional, List
 
 from flask import current_app as app
 from google.cloud.storage import Blob
@@ -10,25 +10,27 @@ from sqlalchemy import (
     Column,
     Boolean,
     DateTime,
-    ForeignKey,
     Integer,
     BigInteger,
     String,
-    VARCHAR,
     Enum,
     Index,
     func,
+    CheckConstraint,
+    ForeignKeyConstraint,
 )
-from sqlalchemy.orm import relationship
 from sqlalchemy.orm.attributes import flag_modified
 from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy.orm.session import Session
-from sqlalchemy.dialects.postgresql import JSONB, ARRAY, BYTEA
-from sqlalchemy.ext.declarative import declarative_base, declared_attr
+from sqlalchemy.sql import expression
+from sqlalchemy.dialects.postgresql import JSONB
+from sqlalchemy.ext.declarative import declarative_base
 from eve_sqlalchemy.config import DomainConfig, ResourceConfig
 
 from cidc_schemas import prism, unprism
 
+from cidc_api.gcloud_client import publish_artifact_upload, publish_upload_success
+
 ## Constants
 ORGS = ["CIDC", "DFCI", "ICAHN", "STANFORD", "ANDERSON"]
 
@@ -73,37 +75,43 @@ FILE_TYPES = [
 ]
 
 
+class FKResourceConfig(ResourceConfig):
+    def _get_column_fields(self):
+        """
+        Eve-SQLAlchemy's built-in ResourceConfig generator doesn't include foreign keys
+        without relationships in the schema config, but we want to allow this, so
+        we override this method by removing the foreign key filter (`len(f.expression.foreign_keys) == 0)`): 
+        https://github.com/pyeve/eve-sqlalchemy/blob/22bdd96fe5b461fbdfe4a4dfdc394569f7e9b8b4/eve_sqlalchemy/config/resourceconfig.py#L157
+        """
+        return (
+            f.key
+            for f in self._mapper.column_attrs
+            if f.key not in self._ignored_fields
+            and isinstance(f.expression, expression.ColumnElement)
+        )
+
+
 def get_DOMAIN() -> dict:
     """
     Render all cerberus domains for API resources and set up method restrictions
     and role-based access controls.
     """
     domain_config = {}
-    domain_config["new_users"] = ResourceConfig(Users)
-    domain_config["trial_metadata"] = ResourceConfig(TrialMetadata, id_field="trial_id")
-    for model in [Users, ManifestUploads, AssayUploads, Permissions, DownloadableFiles]:
-        domain_config[model.__tablename__] = ResourceConfig(model)
+    domain_config["new_users"] = FKResourceConfig(Users)
+    domain_config["trial_metadata"] = FKResourceConfig(
+        TrialMetadata, id_field="trial_id"
+    )
+    for model in [Users, UploadJobs, Permissions, DownloadableFiles]:
+        domain_config[model.__tablename__] = FKResourceConfig(model)
 
-    # Eve-sqlalchemy needs this to be specified explicitly for foreign key relations
-    related_resources = {
-        (Permissions, "to_user"): "users",
-        (Permissions, "by_user"): "users",
-        (Permissions, "trial"): "trial_metadata",
-        (AssayUploads, "uploader"): "users",
-        (AssayUploads, "trial"): "trial_metadata",
-        (ManifestUploads, "uploader"): "users",
-        (ManifestUploads, "trial"): "trial_metadata",
-        (DownloadableFiles, "trial"): "trial_metadata",
-    }
-
-    domain = DomainConfig(domain_config, related_resources).render()
+    domain = DomainConfig(domain_config).render()
 
     # Restrict operations on the 'new_users' resource:
     # * A new_user cannot be created with a role or an approval date
     # * A new_user can _only_ be created (not updated)
     del domain["new_users"]["schema"]["role"]
     del domain["new_users"]["schema"]["approval_date"]
-    domain["new_users"]["item_methods"] = []
+    domain["new_users"]["item_lookup"] = False
     domain["new_users"]["resource_methods"] = ["POST"]
 
     # Restrict operations on resources that only admins should be able to access
@@ -119,31 +127,21 @@ def get_DOMAIN() -> dict:
     domain["permissions"]["allowed_item_roles"] = [CIDCRole.ADMIN.value]
     domain["permissions"]["item_methods"] = ["GET", "DELETE", "PATCH"]
 
-    # Restrict operations on the 'assay_uploads' resource:
-    # * only admins can list 'assay_uploads' (TODO: we may want people to be able to view their own uploads)
-    # * only admins, cimac biofx users, and cidc biofx users can GET items or PATCH 'assay_uploads'
+    # Restrict operations on the 'upload_jobs' resource:
+    # * only admins can list 'upload_jobs' (TODO: we may want people to be able to view their own UploadJobs)
+    # * only admins, nci biobank users, cimac biofx users, and cidc biofx users can GET items or PATCH 'upload_jobs'
     admin_cimac_cidc = [
         CIDCRole.ADMIN.value,
+        CIDCRole.NCI_BIOBANK_USER.value,
         CIDCRole.CIMAC_BIOFX_USER.value,
         CIDCRole.CIDC_BIOFX_USER.value,
     ]
-    domain["assay_uploads"]["allowed_read_roles"] = [CIDCRole.ADMIN.value]
-    domain["assay_uploads"]["allowed_item_read_roles"] = admin_cimac_cidc
-    domain["assay_uploads"]["allowed_write_roles"] = admin_cimac_cidc
-    domain["assay_uploads"]["allowed_item_write_roles"] = admin_cimac_cidc
-    domain["assay_uploads"]["resource_methods"] = ["GET"]
-    domain["assay_uploads"]["item_methods"] = ["GET", "PATCH"]
-
-    # Restrict operations on the 'manifest_uploads' resource:
-    # * only admins can GET 'manifest_uploads'
-    # * only admins and NCI users can GET items or PATCH 'manifest_uploads'
-    admin_and_nci = [CIDCRole.ADMIN.value, CIDCRole.NCI_BIOBANK_USER.value]
-    domain["manifest_uploads"]["allowed_read_roles"] = [CIDCRole.ADMIN.value]
-    domain["manifest_uploads"]["allowed_item_read_roles"] = admin_and_nci
-    domain["manifest_uploads"]["allowed_write_roles"] = admin_and_nci
-    domain["manifest_uploads"]["allowed_item_write_roles"] = admin_and_nci
-    domain["manifest_uploads"]["resource_methods"] = ["GET"]
-    domain["manifest_uploads"]["item_methods"] = ["GET", "PATCH"]
+    domain["upload_jobs"]["allowed_read_roles"] = [CIDCRole.ADMIN.value]
+    domain["upload_jobs"]["allowed_item_read_roles"] = admin_cimac_cidc
+    domain["upload_jobs"]["allowed_write_roles"] = admin_cimac_cidc
+    domain["upload_jobs"]["allowed_item_write_roles"] = admin_cimac_cidc
+    domain["upload_jobs"]["resource_methods"] = ["GET"]
+    domain["upload_jobs"]["item_methods"] = ["GET", "PATCH"]
 
     # Restrict operations on the 'downloadable_files' resource:
     # * downloadable_files are read-only through the API
@@ -200,6 +198,16 @@ class CommonColumns(BaseModel):
         """Find the record with this id"""
         return session.query(cls).get(id)
 
+    @classmethod
+    @with_default_session
+    def get_distinct(cls, column_name: str, session: Session):
+        """Get a list of distinct values for the given column."""
+        assert (
+            column_name in cls.__table__.columns.keys()
+        ), f"{cls.__tablename__} has no column {column_name}"
+
+        return list(v[0] for v in session.query(getattr(cls, column_name)).distinct())
+
 
 class Users(CommonColumns):
     __tablename__ = "users"
@@ -245,25 +253,33 @@ class Users(CommonColumns):
 
 class Permissions(CommonColumns):
     __tablename__ = "permissions"
+    __table_args__ = (
+        ForeignKeyConstraint(
+            ["granted_by_user"],
+            ["users.id"],
+            name="ix_permissions_granted_by_user",
+            ondelete="CASCADE",
+        ),
+        ForeignKeyConstraint(
+            ["granted_to_user"],
+            ["users.id"],
+            name="ix_permissions_granted_to_user",
+            ondelete="CASCADE",
+        ),
+        ForeignKeyConstraint(
+            ["trial_id"],
+            ["trial_metadata.trial_id"],
+            name="ix_permissions_trial_id",
+            ondelete="CASCADE",
+        ),
+    )
 
     # If user who granted this permission is deleted, this permission will be deleted.
     # TODO: is this what we want?
-    granted_by_user = Column(Integer, ForeignKey("users.id", ondelete="CASCADE"))
-    by_user = relationship("Users", foreign_keys=[granted_by_user])
-    granted_to_user = Column(
-        Integer, ForeignKey("users.id", ondelete="CASCADE"), index=True
-    )
-    to_user = relationship("Users", foreign_keys=[granted_to_user])
-
-    trial_id = Column(
-        String,
-        ForeignKey("trial_metadata.trial_id", ondelete="CASCADE"),
-        nullable=False,
-        index=True,
-    )
-    trial = relationship("TrialMetadata", foreign_keys=[trial_id])
-
-    assay_type = Column(String, nullable=False)
+    granted_by_user = Column(Integer)
+    granted_to_user = Column(Integer, nullable=False, index=True)
+    trial_id = Column(String, nullable=False, index=True)
+    upload_type = Column(String, nullable=False)
 
     @staticmethod
     @with_default_session
@@ -279,7 +295,7 @@ class Permissions(CommonColumns):
         """Check if a Permissions record exists for the given user, trial, and type."""
         return (
             session.query(Permissions)
-            .filter_by(granted_to_user=user.id, trial_id=trial_id, assay_type=type_)
+            .filter_by(granted_to_user=user.id, trial_id=trial_id, upload_type=type_)
             .first()
         )
 
@@ -405,11 +421,11 @@ class TrialMetadata(CommonColumns):
 
     @staticmethod
     def merge_gcs_artifact(
-        metadata: dict, assay_type: str, uuid: str, gcs_object: Blob
+        metadata: dict, upload_type: str, uuid: str, gcs_object: Blob
     ):
         return prism.merge_artifact(
             ct=metadata,
-            assay_type=assay_type,
+            assay_type=upload_type,  # assay_type is the old name for upload_type
             artifact_uuid=uuid,
             object_url=gcs_object.name,
             file_size_bytes=gcs_object.size,
@@ -437,98 +453,19 @@ class TrialMetadata(CommonColumns):
         return unprism.unprism_samples(trial.metadata_json)
 
 
-class UploadForeignKeys:
-    # Link to the user who created this upload.
-    @declared_attr
-    def uploader_email(cls):
-        return Column(String, ForeignKey("users.email", onupdate="CASCADE"))
-
-    @declared_attr
-    def uploader(cls):
-        return relationship("Users", foreign_keys=[cls.uploader_email])
-
-    # The trial that this is an upload for.
-    # This foreign key constraint means that it won't be possible
-    # to create an upload for a trial that doesn't exist.
-    @declared_attr
-    def trial_id(cls):
-        return Column(
-            String, ForeignKey("trial_metadata.trial_id"), nullable=False, index=True
-        )
-
-    @declared_attr
-    def trial(cls):
-        return relationship("TrialMetadata", foreign_keys=[cls.trial_id])
-
-    # The object URI for the raw excel form associated with this upload
-    gcs_xlsx_uri = Column(String, nullable=False)
-
-    def alert_upload_success(self, trial: TrialMetadata):
-        """Send an email notification that an upload has succeeded."""
-        # (import these here to avoid a circular import error)
-        from cidc_api import emails
-
-        # Send admin notification email
-        emails.new_upload_alert(self, trial.metadata_json, send_email=True)
-
-
-class ManifestUploads(CommonColumns, UploadForeignKeys):
-    __tablename__ = "manifest_uploads"
-    # A type of manifest (pbmc, plasma, ...) this upload is related to
-    manifest_type = Column(String, nullable=False)
-    # The parsed JSON manifest blob for this upload
-    metadata_patch = Column(JSONB, nullable=False)
-    # tracks the GCS URI of the .xlsx file used for this upload
-    gcs_xlsx_uri = Column(String, nullable=False)
-
-    @staticmethod
-    @with_default_session
-    def create(
-        manifest_type: str,
-        uploader_email: str,
-        metadata: dict,
-        gcs_xlsx_uri: str,
-        trial: TrialMetadata,
-        session: Session,
-        commit: bool = True,
-        send_email: bool = False,
-    ):
-        """Create a new ManifestUpload for the given trial manifest patch."""
-        assert (
-            prism.PROTOCOL_ID_FIELD_NAME in metadata
-        ), "metadata patch must have a trial ID"
-
-        assert trial.trial_id == metadata[prism.PROTOCOL_ID_FIELD_NAME]
-
-        upload = ManifestUploads(
-            trial_id=trial.trial_id,
-            manifest_type=manifest_type,
-            metadata_patch=metadata,
-            uploader_email=uploader_email,
-            gcs_xlsx_uri=gcs_xlsx_uri,
-            _etag=make_etag(manifest_type, metadata, uploader_email),
-        )
-        session.add(upload)
-        if commit:
-            session.commit()
-
-        if send_email:
-            upload.alert_upload_success(trial)
-
-        return upload
-
-
-class AssayUploadStatus(EnumBaseClass):
+class UploadJobStatus(EnumBaseClass):
     STARTED = "started"
     # Set by CLI based on GCS upload results
     UPLOAD_COMPLETED = "upload-completed"
     UPLOAD_FAILED = "upload-failed"
-    # Set by ingest_uploads cloud function based on merge / transfer results
+    # Set by ingest_UploadJobs cloud function based on merge / transfer results
     MERGE_COMPLETED = "merge-completed"
     MERGE_FAILED = "merge-failed"
 
     @classmethod
-    def is_valid_transition(cls, current: str, target: str) -> bool:
+    def is_valid_transition(
+        cls, current: str, target: str, is_manifest: bool = False
+    ) -> bool:
         """
         Enforce logic about which state transitions are valid. E.g.,
         an upload whose status is "merge-completed" should never be updated
@@ -546,34 +483,65 @@ class AssayUploadStatus(EnumBaseClass):
                     return False
             if c in merge_statuses:
                 return False
-            if c == cls.STARTED and t in merge_statuses:
+            if c == cls.STARTED and t in merge_statuses and not is_manifest:
                 return False
         return True
 
 
-STATUSES = [s.value for s in AssayUploadStatus]
+UPLOAD_STATUSES = [s.value for s in UploadJobStatus]
 
 
-class AssayUploads(CommonColumns, UploadForeignKeys):
-    __tablename__ = "assay_uploads"
+class UploadJobs(CommonColumns):
+    __tablename__ = "upload_jobs"
+    # An upload job must contain a gcs_file_map is it isn't a manifest upload
+    __table_args__ = (
+        CheckConstraint(f"multifile = true OR gcs_file_map != null"),
+        ForeignKeyConstraint(
+            ["uploader_email"],
+            ["users.email"],
+            name="upload_jobs_uploader_email_fkey",
+            onupdate="CASCADE",
+        ),
+        ForeignKeyConstraint(
+            ["trial_id"],
+            ["trial_metadata.trial_id"],
+            name="assay_uploads_trial_id_fkey",
+        ),
+    )
+
     # The current status of the upload job
-    status = Column(Enum(*STATUSES, name="assay_upload_status"), nullable=False)
+    status = Column(Enum(*UPLOAD_STATUSES, name="upload_job_status"), nullable=False)
     # Text containing feedback on why the upload status is what it is
     status_details = Column(String, nullable=True)
-    # The object names for the files to be uploaded mapped to upload_placeholder uuids
-    gcs_file_map = Column(JSONB, nullable=False)
+    # Whether the upload contains multiple files
+    multifile = Column(Boolean, nullable=False)
+    # For multifile UploadJobs, object names for the files to be uploaded mapped to upload_placeholder uuids.
+    # For single file UploadJobs, this field is null.
+    gcs_file_map = Column(JSONB, nullable=True)
     # track the GCS URI of the .xlsx file used for this upload
     gcs_xlsx_uri = Column(String, nullable=False)
     # The parsed JSON metadata blob associated with this upload
-    assay_patch = Column(JSONB, nullable=False)
-    # A type of assay (wes, olink, ...) this upload is related to
-    assay_type = Column(String, nullable=False)
+    metadata_patch = Column(JSONB, nullable=False)
+    # The type of upload (pbmc, wes, olink, wes_analysis, ...)
+    upload_type = Column(String, nullable=False)
+    # Link to the user who created this upload.
+    uploader_email = Column(String, nullable=False)
+    # The trial that this is an upload for.
+    trial_id = Column(String, nullable=False, index=True)
 
     # Create a GIN index on the GCS object names
     _gcs_objects_idx = Index(
-        "assay_uploads_gcs_gcs_file_map_idx", gcs_file_map, postgresql_using="gin"
+        "upload_jobs_gcs_gcs_file_map_idx", gcs_file_map, postgresql_using="gin"
     )
 
+    def alert_upload_success(self, trial: TrialMetadata):
+        """Send an email notification that an upload has succeeded."""
+        # (import these here to avoid a circular import error)
+        from cidc_api import emails
+
+        # Send admin notification email
+        emails.new_upload_alert(self, trial.metadata_json, send_email=True)
+
     def upload_uris_with_data_uris_with_uuids(self):
         for upload_uri, uuid in self.gcs_file_map.items():
             # URIs in the upload bucket have a structure like (see ingestion.upload_assay)
@@ -587,61 +555,74 @@ class AssayUploads(CommonColumns, UploadForeignKeys):
     @staticmethod
     @with_default_session
     def create(
-        assay_type: str,
+        upload_type: str,
         uploader_email: str,
         gcs_file_map: dict,
         metadata: dict,
         gcs_xlsx_uri: str,
         session: Session,
         commit: bool = True,
+        send_email: bool = False,
+        status: UploadJobStatus = UploadJobStatus.STARTED.value,
     ):
         """Create a new upload job for the given trial metadata patch."""
         assert prism.PROTOCOL_ID_FIELD_NAME in metadata, "metadata must have a trial ID"
+
+        is_manifest_upload = upload_type in prism.SUPPORTED_MANIFESTS
+        assert (
+            gcs_file_map is not None or is_manifest_upload
+        ), "assay/analysis uploads must have a gcs_file_map"
+
         trial_id = metadata[prism.PROTOCOL_ID_FIELD_NAME]
 
-        job = AssayUploads(
+        job = UploadJobs(
+            multifile=is_manifest_upload,
             trial_id=trial_id,
-            assay_type=assay_type,
+            upload_type=upload_type,
             gcs_file_map=gcs_file_map,
-            assay_patch=metadata,
+            metadata_patch=metadata,
             uploader_email=uploader_email,
             gcs_xlsx_uri=gcs_xlsx_uri,
-            status=AssayUploadStatus.STARTED.value,
+            status=status,
             _etag=make_etag(
-                assay_type,
+                upload_type,
                 gcs_file_map,
                 metadata,
                 uploader_email,
-                AssayUploadStatus.STARTED.value,
+                UploadJobStatus.STARTED.value,
             ),
         )
         session.add(job)
         if commit:
             session.commit()
 
+        if send_email:
+            trial = TrialMetadata.find_by_trial_id(trial_id)
+            job.alert_upload_success(trial)
+
         return job
 
     @staticmethod
     @with_default_session
     def merge_extra_metadata(job_id, files, session):
 
-        job = AssayUploads.find_by_id(job_id, session=session)
+        job = UploadJobs.find_by_id(job_id, session=session)
 
         print(f"About to merge extra md to {job.id}/{job.status}")
 
         for uuid, file in files.items():
             print(f"About to parse/merge extra md on {uuid}")
-            job.assay_patch, updated_artifact, _ = prism.merge_artifact_extra_metadata(
-                job.assay_patch, uuid, job.assay_type, file
+            job.metadata_patch, updated_artifact, _ = prism.merge_artifact_extra_metadata(
+                job.metadata_patch, uuid, job.upload_type, file
             )
             print(f"Updated md for {uuid}: {updated_artifact.keys()}")
 
         # A workaround fix for JSON field modifications not being tracked
         # by SQLalchemy for some reason. Using MutableDict.as_mutable(JSON)
         # in the model doesn't seem to help.
-        flag_modified(job, "assay_patch")
+        flag_modified(job, "metadata_patch")
 
-        print(f"Updated {job.id}/{job.status} patch: {job.assay_patch}")
+        print(f"Updated {job.id}/{job.status} patch: {job.metadata_patch}")
         session.commit()
 
     @classmethod
@@ -658,13 +639,13 @@ class AssayUploads(CommonColumns, UploadForeignKeys):
     ):
         """Set own status to reflect successful merge and trigger email notifying CIDC admins."""
         # Do status update if the transition is valid
-        if not AssayUploadStatus.is_valid_transition(
-            self.status, AssayUploadStatus.MERGE_COMPLETED.value
+        if not UploadJobStatus.is_valid_transition(
+            self.status, UploadJobStatus.MERGE_COMPLETED.value
         ):
             raise Exception(
                 f"Cannot declare ingestion success given current status: {self.status}"
             )
-        self.status = AssayUploadStatus.MERGE_COMPLETED.value
+        self.status = UploadJobStatus.MERGE_COMPLETED.value
 
         if commit:
             session.commit()
@@ -680,6 +661,13 @@ class DownloadableFiles(CommonColumns):
     """
 
     __tablename__ = "downloadable_files"
+    __table_args__ = (
+        ForeignKeyConstraint(
+            ["trial_id"],
+            ["trial_metadata.trial_id"],
+            name="downloadable_files_trial_id_fkey",
+        ),
+    )
 
     file_name = Column(String, nullable=False)
     file_size_bytes = Column(BigInteger, nullable=False)
@@ -687,16 +675,18 @@ class DownloadableFiles(CommonColumns):
     # NOTE: this column actually has type CITEXT.
     data_format = Column(String, nullable=False)
     additional_metadata = Column(JSONB, nullable=True)
-    # TODO rename assay_type, because we store manifests in there too.
+    # TODO rename upload_type, because we store manifests in there too.
     # NOTE: this column actually has type CITEXT.
-    assay_type = Column(String, nullable=False)
+    upload_type = Column(String, nullable=False)
     md5_hash = Column(String, nullable=True)
     crc32c_hash = Column(String, nullable=True)
-    trial_id = Column(String, ForeignKey("trial_metadata.trial_id"), nullable=False)
-    trial = relationship(TrialMetadata, foreign_keys=[trial_id])
+    trial_id = Column(String, nullable=False)
     object_url = Column(String, nullable=False, index=True, unique=True)
     visible = Column(Boolean, default=True)
 
+    # Would a bioinformatician likely use this file in an analysis?
+    analysis_friendly = Column(Boolean, default=False)
+
     # Visualization data columns (should always be nullable)
     clustergrammer = Column(JSONB, nullable=True)
     ihc_combined_plot = Column(JSONB, nullable=True)
@@ -705,11 +695,12 @@ class DownloadableFiles(CommonColumns):
     @with_default_session
     def create_from_metadata(
         trial_id: str,
-        assay_type: str,
+        upload_type: str,
         file_metadata: dict,
         session: Session,
         additional_metadata: Optional[dict] = None,
         commit: bool = True,
+        alert_artifact_upload: bool = False,
     ):
         """
         Create a new DownloadableFiles record from artifact metadata.
@@ -719,7 +710,7 @@ class DownloadableFiles(CommonColumns):
         supported_columns = DownloadableFiles.__table__.columns.keys()
         filtered_metadata = {
             "trial_id": trial_id,
-            "assay_type": assay_type,
+            "upload_type": upload_type,
             "additional_metadata": additional_metadata,
         }
         for key, value in file_metadata.items():
@@ -729,9 +720,10 @@ class DownloadableFiles(CommonColumns):
 
         etag = make_etag(*(filtered_metadata.values()))
 
+        object_url = filtered_metadata["object_url"]
         df = (
             session.query(DownloadableFiles)
-            .filter_by(object_url=filtered_metadata["object_url"])
+            .filter_by(object_url=object_url)
             .with_for_update()
             .first()
         )
@@ -746,17 +738,21 @@ class DownloadableFiles(CommonColumns):
         if commit:
             session.commit()
 
+        if alert_artifact_upload:
+            publish_artifact_upload(object_url)
+
         return df
 
     @staticmethod
     @with_default_session
     def create_from_blob(
         trial_id: str,
-        assay_type: str,
+        upload_type: str,
         data_format: str,
         blob: Blob,
         session: Session,
         commit: bool = True,
+        alert_artifact_upload: bool = False,
     ):
         """
         Create a new DownloadableFiles record from from a GCS blob,
@@ -774,7 +770,7 @@ class DownloadableFiles(CommonColumns):
             df = DownloadableFiles()
 
         df.trial_id = trial_id
-        df.assay_type = assay_type
+        df.upload_type = upload_type
         df.data_format = data_format
         df.object_url = blob.name
         df.file_name = blob.name
@@ -788,6 +784,9 @@ class DownloadableFiles(CommonColumns):
         if commit:
             session.commit()
 
+        if alert_artifact_upload:
+            publish_artifact_upload(blob.name)
+
         return df
 
     @staticmethod
